library(GenomicRanges)

## read in peak calling results                                                          
peaks.pol2 = read.table("K562_Pol2_peaks.bed")
peaks.cmyc = read.table("K562_Cmyc_peaks.bed")

## look at the first a few peaks                                                         
head(peaks.pol2)
head(peaks.cmyc)

## create "GRanges" objects for the peaks                                                
peaks.pol2.gr = GRanges(seqnames=Rle(peaks.pol2[,1]),
  ranges=IRanges(peaks.pol2[,2], peaks.pol2[,3]))
peaks.cmyc.gr = GRanges(seqnames=Rle(peaks.cmyc[,1]),
  ranges=IRanges(peaks.cmyc[,2], peaks.cmyc[,3]))

## look at the GRanges objects                                                           
head(peaks.pol2.gr)
head(peaks.cmyc.gr)

## look at the overlaps - overlap percentage is high                                     
mean(peaks.pol2.gr %over% peaks.cmyc.gr)
mean(peaks.cmyc.gr %over% peaks.pol2.gr)

library(GenomicFeatures)
refGene.hg18 = loadDb("refGene.hg18.sqlite")
tx = transcripts(refGene.hg18)
tx.chr22 = unique(tx[seqnames(tx)=="chr22"]) ## genes on  chr 22     
tx.chr22  ## 925 transcripts on chr22

## first obtain TSS.                                     
## This is a little tricky, be careful in strands directions.                            
strands=strand(tx.chr22)
ix.gene.minus=which(strands=="-")
TSS=start(tx.chr22)
TSS[ix.gene.minus]=end(tx.chr22)[ix.gene.minus]
## create 50 bp bins around TSS.
winsize=50
ext = 1000
allss=sapply(TSS, function(x) seq(x-ext, x+ext-1, by=winsize))
## create GRanges
allchrs=as.character(seqnames(tx.chr22))
allseq=Rle(allchrs,rep(ext/winsize*2,length(allchrs)))
allrange=IRanges(start=allss, end=allss+winsize-1)
TSS.GRanges=GRanges(seqnames=allseq, ranges=allrange)

library(Rsamtools)
what = c("rname", "strand", "pos", "qwidth")
param = ScanBamParam(what = what)
bam=scanBam("K562Cmyc_chr22.bam", param=param)[[1]]
IRange.reads=GRanges(seqnames=Rle(bam$rname),
        ranges=IRanges(bam$pos, width=bam$qwidth))
tmp=countOverlaps(TSS.GRanges, IRange.reads)
counts.Cmyc.win=matrix(tmp, ncol=40, byrow=TRUE)
png("quick-test-plot.png")
plot(colMeans(counts.Cmyc.win), type="b", xaxt="n", xlab="position", ylab="Average Cmyc binding")
axis(1, c(1, 10,20, 30,40), labels=c("-500", "-200", "TSS", "250", "500"))
dev.off()
